use std::{cmp::Eq, hash::Hash};

/// Represents a specific texture defined in the content dir.
#[derive(Debug, Clone, Copy)]
pub struct TextureHandle {
	/// The index of this texture in content.textures
	pub(crate) index: usize,

	/// The aspect ratio of this texture (width / height)
	pub aspect: f32,
}

impl Hash for TextureHandle {
	fn hash<H: std::hash::Hasher>(&self, state: &mut H) {
		self.index.hash(state)
	}
}

impl Eq for TextureHandle {}
impl PartialEq for TextureHandle {
	fn eq(&self, other: &Self) -> bool {
		self.index.eq(&other.index)
	}
}

/// A lightweight representation of a faction
#[derive(Debug, Clone, Copy, Hash, PartialEq, Eq)]
pub struct FactionHandle {
	/// The index of this faction in content.factions
	/// TODO: pub in crate, currently for debug.
	pub index: usize,
}
